/****************************************************************************************/
/*  StBody.H                                                                            */
/*                                                                                      */
/*  Author: Alejandro F. Reimondo	                                                    */
/*  Description: Visual Smalltalk extesions to standard API.		                    */
/*                                                                                      */
/****************************************************************************************/
#ifndef StBody_H
#define StBody_H 

#include "body.h"

#ifdef __cplusplus
extern "C" {
#endif

GENESISAPI geBody *GENESISCC stBody_Create(void);
GENESISAPI void GENESISCC stBody_Destroy(geBody **B);
GENESISAPI geBoolean GENESISCC stBody_IsValid(const geBody *B);
GENESISAPI geBoolean GENESISCC stBody_GetGeometryStats(const geBody *B, int lod, int *Vertices, int *Faces, int *Normals);
GENESISAPI geBoolean GENESISCC stBody_AddFace(	geBody *B,
		const geVec3d *Vertex1, const geVec3d *Normal1, 
		geFloat U1, geFloat V1, int BoneIndex1,
		const geVec3d *Vertex2, const geVec3d *Normal2, 
		geFloat U2, geFloat V2, int BoneIndex2,
		const geVec3d *Vertex3, const geVec3d *Normal3, 
		geFloat U3, geFloat V3, int BoneIndex3,
		int MaterialIndex);

GENESISAPI geBoolean GENESISCC stBody_AddMaterial( geBody *B, 
		const char *MaterialName, 
		geBitmap *Bitmap,
		geFloat Red, 
		geFloat Green, 
		geFloat Blue,
		int *MaterialIndex);

GENESISAPI geBoolean GENESISCC stBody_GetMaterial(const geBody *Body, int MaterialIndex,
		const char **MaterialName,
		geBitmap **Bitmap, geFloat *Red, geFloat *Green, geFloat *Blue);

GENESISAPI geBoolean GENESISCC stBody_SetMaterial(geBody *Body, int MaterialIndex,
		geBitmap *Bitmap,  geFloat Red,  geFloat Green,  geFloat Blue);

GENESISAPI int GENESISCC stBody_GetMaterialCount(const geBody *B);

GENESISAPI geBoolean GENESISCC stBody_AddBone( geBody *B, 
		int ParentBoneIndex,
		const char *BoneName, 
		const geXForm3d *AttachmentMatrix,
		int *BoneIndex);

GENESISAPI geBoolean GENESISCC stBody_ComputeLevelsOfDetail( geBody *B ,int Levels);

GENESISAPI int GENESISCC stBody_GetBoneCount(const geBody *B);

GENESISAPI void GENESISCC stBody_GetBone(	const geBody *B, 
		int BoneIndex, 
		const char **BoneName,
		geXForm3d *Attachment, 
		int *ParentBoneIndex);

GENESISAPI int32 GENESISCC stBody_GetBoneNameChecksum(const geBody *B);

GENESISAPI void GENESISCC stBody_SetBoundingBox( geBody *B,
		int BoneIndex,
		const geVec3d *MinimumBoxCorner,
		const geVec3d *MaximumBoxCorner);
 
GENESISAPI geBoolean GENESISCC stBody_GetBoundingBox( const geBody *B, 
		int BoneIndex,
		geVec3d *MinimumBoxCorner,
		geVec3d *MaximumBoxCorner);

GENESISAPI geBoolean GENESISCC stBody_GetBoneByName(const geBody* B,
	const char* BoneName,
	int* pBoneIndex,
	geXForm3d* Attachment,
	int* pParentBoneIndex);

GENESISAPI geBoolean GENESISCC stBody_WriteToFile(const geBody *B, geVFile *pFile);
GENESISAPI geBody  *GENESISCC  stBody_CreateFromFile(geVFile *pFile);

#ifdef __cplusplus
}
#endif

#endif
					